==> ah-react-ui-1.0.69.tgz: package/lib/esm/filters/lib.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { createStore, createApi, forward, sample, combine } from "effector";
//TODO add reset event
export var createFilter = function (config) {
    var _a;
    var filterValue = config.filterValue, filterLabel = config.filterLabel, casesConfigs = config.cases;
    var $activeValues = createStore([]);
    var $query = combine((_a = {}, _a[filterValue] = $activeValues, _a));
    var cases = {};
    var queryString = window.location.search;
    var urlParams = new URLSearchParams(queryString);
    console.log(urlParams.get(filterValue));
    var _loop_1 = function (caseName) {
        if (!casesConfigs.hasOwnProperty(caseName))
            return "continue";
        var caseConfig = casesConfigs[caseName];
        var $active = createStore(false);
        var $disabled = createStore(false);
        var _b = createApi($active, {
            activate: function () { return true; },
            deactivate: function () { return false; },
        }), activate = _b.activate, deactivate = _b.deactivate;
        var _c = createApi($disabled, {
            enable: function () { return false; },
            disable: function () { return true; },
        }), enable = _c.enable, disable = _c.disable;
        forward({ from: disable, to: deactivate });
        sample({
            clock: activate,
            source: $activeValues,
            fn: function (s) {
                s.push(caseConfig.value);
                return __spreadArray([], s, true);
            },
            target: $activeValues
        });
        sample({
            clock: deactivate,
            source: $activeValues,
            fn: function (s) { return s.filter(function (item) { return item !== caseConfig.value; }); },
            target: $activeValues
        });
        cases[caseName] = {
            activate: activate,
            deactivate: deactivate,
            $active: $active,
            disable: disable,
            $disabled: $disabled,
            enable: enable,
            value: caseConfig.value,
            label: caseConfig.label
        };
    };
    // cards-generate units
    for (var caseName in casesConfigs) {
        _loop_1(caseName);
    }
    return {
        filterLabel: filterLabel,
        filterValue: filterValue,
        cases: cases,
        $activeValues: $activeValues,
        $query: $query
    };
};
export var bindQueriesForRoute = function (config) {
    var route = config.route, queries = config.queries;
    queries.forEach(function ($query) {
        sample({
            clock: $query,
            source: [route.$params, route.$query],
            fn: function (_a, filterQ) {
                var params = _a[0], routeQ = _a[1];
                return { params: params, query: __assign(__assign({}, routeQ), filterQ) };
            },
            target: route.navigate,
        });
    });
};

==> ah-react-ui-1.0.71.tgz: package/lib/esm/filters/lib.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import { createStore, createApi, forward, sample, combine } from "effector";
//TODO add reset event
export var createFilter = function (config) {
    var _a;
    var _b;
    var filterValue = config.filterValue, filterLabel = config.filterLabel, casesConfigs = config.cases;
    var $activeValues = createStore([]);
    var $query = combine((_a = {}, _a[filterValue] = $activeValues, _a));
    var cases = {};
    var queryString = window.location.search;
    var urlParams = (_b = new URLSearchParams(queryString).get(filterValue)) === null || _b === void 0 ? void 0 : _b.split(',');
    var _loop_1 = function (caseName) {
        if (!casesConfigs.hasOwnProperty(caseName))
            return "continue";
        var caseConfig = casesConfigs[caseName];
        var $active = createStore(urlParams ? urlParams.includes(caseConfig.value) : false);
        var $disabled = createStore(false);
        var _c = createApi($active, {
            activate: function () { return true; },
            deactivate: function () { return false; },
        }), activate = _c.activate, deactivate = _c.deactivate;
        var _d = createApi($disabled, {
            enable: function () { return false; },
            disable: function () { return true; },
        }), enable = _d.enable, disable = _d.disable;
        forward({ from: disable, to: deactivate });
        sample({
            clock: activate,
            source: $activeValues,
            fn: function (s) {
                s.push(caseConfig.value);
                return __spreadArray([], s, true);
            },
            target: $activeValues
        });
        sample({
            clock: deactivate,
            source: $activeValues,
            fn: function (s) { return s.filter(function (item) { return item !== caseConfig.value; }); },
            target: $activeValues
        });
        cases[caseName] = {
            activate: activate,
            deactivate: deactivate,
            $active: $active,
            disable: disable,
            $disabled: $disabled,
            enable: enable,
            value: caseConfig.value,
            label: caseConfig.label
        };
    };
    // cards-generate units
    for (var caseName in casesConfigs) {
        _loop_1(caseName);
    }
    return {
        filterLabel: filterLabel,
        filterValue: filterValue,
        cases: cases,
        $activeValues: $activeValues,
        $query: $query
    };
};
export var bindQueriesForRoute = function (config) {
    var route = config.route, queries = config.queries;
    queries.forEach(function ($query) {
        sample({
            clock: $query,
            source: [route.$params, route.$query],
            fn: function (_a, filterQ) {
                var params = _a[0], routeQ = _a[1];
                return { params: params, query: __assign(__assign({}, routeQ), filterQ) };
            },
            target: route.navigate,
        });
    });
};
